extends KinematicBody2D

var MAX_SPEED = 200
var ACCELERATION = 1000
var FRICTION = 1000
var MAX_LIFE = 30

var vel = Vector2.ZERO
var curLife = MAX_LIFE

var coroutines = []

enum EInput{
	UP,
	RIGHT,
	DOWN,
	LEFT
}

const baseInputs = ["ui_up", "ui_right", "ui_down", "ui_left"]
var inputs = ["ui_up", "ui_right", "ui_down", "ui_left"]

onready var animationPlayer = $AnimationPlayer
onready var animationTree = $AnimationTree
onready var animationState = animationTree.get("parameters/playback")

func _process(delta):
	updatePaintEffects(delta)
	curLife -= delta
	if curLife <= 0:
		#fin du game laul
		pass

func _physics_process(delta):
	var input_vector = Vector2.ZERO
	
	if self.name == "Player1":
		input_vector.x = Input.get_action_strength(inputs[EInput.RIGHT]) - Input.get_action_strength(inputs[EInput.LEFT])
		input_vector.y = Input.get_action_strength(inputs[EInput.DOWN]) - Input.get_action_strength(inputs[EInput.UP])
	elif self.name == "Player2":
		input_vector.x = Input.get_action_strength(inputs[EInput.RIGHT] + "2") - Input.get_action_strength(inputs[EInput.LEFT] + "2")
		input_vector.y = Input.get_action_strength(inputs[EInput.DOWN] + "2") - Input.get_action_strength(inputs[EInput.UP] + "2")
	
	input_vector = input_vector.normalized()
	
	if input_vector != Vector2.ZERO:
		animationTree.set("parameters/Idle/blend_position", input_vector)
		animationTree.set("parameters/Run/blend_position", input_vector)
		animationState.travel("Run")
		vel = vel.move_toward(input_vector * MAX_SPEED, ACCELERATION * delta)
	else:
		animationState.travel("Idle")
		vel = vel.move_toward(Vector2.ZERO, FRICTION * delta)
	
	vel = move_and_slide(vel)

	
func updatePaintEffects(delta):	
	var sprite = get_node("Sprite")		
	var updated = []	
	for rout in coroutines:				
		if rout != null && rout.is_valid():
			var new_rout = rout.resume(delta)		
			if new_rout != null && new_rout.is_valid():
				updated.append(new_rout)				
		coroutines.remove(coroutines.find(rout))
						
	for rout in updated:
		coroutines.append(rout)

func addCoroutine(routine):
	coroutines.append(routine)
